jumany
======
Python interface for JUMAN Morphological analysis system.

`JUMAN <http://nlp.ist.i.kyoto-u.ac.jp/index.php?JUMAN>`

Requirement
-----------
- POSIX or Windows
- Python 3.3 or above

Installation
------------
```pip install jumany
```

How to use
----------
```import jumany
jumany.open_lib()
jumany.analyze(str_japanese)
```
See `jumany page <https://github.com/yujakudo/jumany/python_module>` for more details in Japanese.

Licenses
--------
- Python scripts: BSD License
- Library: BSD License
- Pre-built libraries for Windows: BSD License, but libraries under LGPL are linked.
